horseman
********

Horseman is a toolkit to build WSGI applications.
It is heavily tested and uses Cython powered libraries.


The philosophy is : "you pay for what you eat".

The code is very minimal and tries to provide key components to build
upon and create a vastly more complex application.

It conforms to the WSGI standards and allows you to use WSGI middlewares.
